import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  max,
  axisLeft,
  axisBottom,
  area,
  curveBasis,
  format
} from 'd3';

const svg = select('svg');

const height = +svg.attr('height');
const width = +svg.attr('width');

const render = data => {
  const title = 'Car Customers Data';
  const xValue = d => d.Years;
  const xAxisLabel = 'Years';
  
	const yValue = d => d.Customers;
  const circleRadius = 6;
  const yAxisLabel = 'Customers';
  
  const margin = {top: 60, right: 50, bottom: 88, left:110}
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleTime()
  .domain(extent(data, xValue))
  .range([0,innerWidth])
  .nice()
  
  const yScale = scaleLinear()
  .domain([0,max(data, yValue)])
  .range([innerHeight,0])
  .nice()
  
  const g = svg.append('g')
  .attr('transform', `translate(${margin.left},${margin.top})`)
  
  const xAxis = axisBottom(xScale)
  .ticks(6)
  .tickSize(-innerHeight)
  .tickPadding(15)
  
  const yAxisTickFormat = number => 
  format('.1s')(number)
  .replace('G','B');
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
  .tickPadding(10)
  .tickFormat(yAxisTickFormat);
  
  const yAxisG = g.append('g')
    .call(yAxis);
  
  yAxisG
  .selectAll('.domain')
          .remove()
  
  yAxisG.append('text')
  .attr('class', 'axis-label')
  .attr('fill', 'black')
  .attr('x', -innerHeight/ 2)
  .attr('y', -63)
  .attr('transform', `rotate(-90)`)
  .attr('text-anchor', 'middle')
  .text(yAxisLabel)
  
  
  const xAxisG = g.append('g').call(xAxis)
  .attr('transform', `translate(0,${innerHeight})`)
    
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
  .attr('class', 'axis-label')
  .attr('fill', 'black')
  .attr('x', innerWidth / 2)
  .attr('y', 75)
  .text(xAxisLabel)
  
  const areaGenerator = area()
  .x(d => xScale(xValue(d)))
  .y0(innerHeight)
  .y1(d => yScale(yValue(d)))
  .curve(curveBasis)
  
  g.append('path')
  .attr('class', 'line-path')
  .attr('d', areaGenerator(data));

  svg.append('text')
  	.attr('class', 'title')
  .attr('x', width / 2)
  .attr('text-anchor', 'middle')
  	.attr('y', 45)
  	.text(title)
}

csv('https://gist.githubusercontent.com/Kiran3295/c4db8542fe05c8711be7d7486f5d982a/raw/384e4ae7e24430dca2af4a1048554740bde6a05a/Customers_Data')
.then(data => {
  console.log(data);
  data.forEach(d => {
    d.Customers= +d.Customers;
    d.Years = d3.timeParse("%Y-%m-%d")(d.Years);
  });
  render(data);
});